==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/ItemSelectorField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/fragment_configuration/field_types/ItemSelectorField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../../../common/AssetSelector.es', './ItemSelectorFieldDelegateTemplate.soy', '../../../../store/ConnectedComponent.es', '../../../../utils/FragmentsEditorDialogUtils', '../../../../utils/FragmentsEditorUpdateUtils.es', './ItemSelectorField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.ConnectedItemSelectorField = exports.ItemSelectorField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("../../../common/AssetSelector.es");

  require("./ItemSelectorFieldDelegateTemplate.soy");

  var _ConnectedComponent = _interopRequireDefault(require("../../../../store/ConnectedComponent.es"));

  var _FragmentsEditorDialogUtils = require("../../../../utils/FragmentsEditorDialogUtils");

  var _FragmentsEditorUpdateUtils = require("../../../../utils/FragmentsEditorUpdateUtils.es");

  var _ItemSelectorField = _interopRequireDefault(require("./ItemSelectorField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ItemSelectorField
   */
  var ItemSelectorField =
  /*#__PURE__*/
  function (_Component) {
    _inherits(ItemSelectorField, _Component);

    function ItemSelectorField() {
      _classCallCheck(this, ItemSelectorField);

      return _possibleConstructorReturn(this, _getPrototypeOf(ItemSelectorField).apply(this, arguments));
    }

    _createClass(ItemSelectorField, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var typeOptions = this.field.typeOptions;

        if (typeOptions) {
          var className = typeOptions.className,
              _typeOptions$enableSe = typeOptions.enableSelectTemplate,
              enableSelectTemplate = _typeOptions$enableSe === void 0 ? false : _typeOptions$enableSe;

          if (className) {
            nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['selectedClassName'], className);
          }

          nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['enableSelectTemplate'], enableSelectTemplate);
        }

        return nextState;
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "syncConfigurationValues",
      value: function syncConfigurationValues() {
        if (this.configurationValues && this.configurationValues[this.field.name] && this.configurationValues[this.field.name].className) {
          var className = this.configurationValues[this.field.name].className;
          var itemType = this.availableAssets.find(function (availableAsset) {
            return availableAsset.className === className;
          });
          this.availableTemplates = itemType.availableTemplates;
        } else {
          this.availableTemplates = [];
        }
      }
      /**
       * Handle the click in the plus button to open the dialog to select an item
       * @review
       */

    }, {
      key: "_handleItemSelectClick",
      value: function _handleItemSelectClick() {
        var className = this.field.typeOptions.className;
        var itemType = this.availableAssets.find(function (availableAsset) {
          return availableAsset.className === className;
        });

        if (itemType) {
          this._openAssetBrowser(itemType.href, itemType.typeName);
        }
      }
      /**
       *
       * @review
       */

    }, {
      key: "_handleSelectTemplateValueChanged",
      value: function _handleSelectTemplateValueChanged() {
        var targetElement = window.event.delegateTarget;
        var selectedItem = this.configurationValues[this.field.name];
        selectedItem.template = targetElement.options[targetElement.selectedIndex].value;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: selectedItem
        });
      }
      /**
       * Handle the click in the item type dropdown
       * @param {Event} event
       * @review
       */

    }, {
      key: "_handleItemTypeClick",
      value: function _handleItemTypeClick(event) {
        var _event$delegateTarget = event.delegateTarget.dataset,
            assetBrowserUrl = _event$delegateTarget.assetBrowserUrl,
            assetBrowserWindowTitle = _event$delegateTarget.assetBrowserWindowTitle;

        this._openAssetBrowser(assetBrowserUrl, assetBrowserWindowTitle);
      }
      /**
       * Opens asset browser
       * @param {string} assetBrowserURL
       * @param {string} assetBrowserWindowTitle
       * @review
       */

    }, {
      key: "_openAssetBrowser",
      value: function _openAssetBrowser(assetBrowserURL, assetBrowserWindowTitle) {
        var _this = this;

        (0, _FragmentsEditorDialogUtils.openAssetBrowser)({
          assetBrowserURL: assetBrowserURL,
          callback: function callback(selectedAssetEntry) {
            _this.emit('fieldValueChanged', {
              name: _this.field.name,
              value: {
                className: selectedAssetEntry.className,
                classNameId: selectedAssetEntry.classNameId,
                classPK: selectedAssetEntry.classPK,
                title: selectedAssetEntry.title
              }
            });
          },
          eventName: "".concat(this.portletNamespace, "selectAsset"),
          modalTitle: assetBrowserWindowTitle
        });
      }
    }]);

    return ItemSelectorField;
  }(_metalComponent["default"]);

  exports.ItemSelectorField = ItemSelectorField;
  ItemSelectorField.STATE = {
    /**
     * Available templates of the current className
     * @default []
     * @instance
     * @memberOf ItemSelectorField
     * @type {array}
     */
    availableTemplates: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      key: _metalState.Config.string(),
      label: _metalState.Config.string()
    })).internal().value([]),

    /**
     * Fragment Entry Link Configuration values
     * @instance
     * @memberOf ItemSelectorField
     * @type {object}
     */
    configurationValues: _metalState.Config.object(),

    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.string(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };
  var ConnectedItemSelectorField = (0, _ConnectedComponent["default"])(ItemSelectorField, ['availableAssets', 'portletNamespace', 'spritemap']);
  exports.ConnectedItemSelectorField = ConnectedItemSelectorField;

  _metalSoy["default"].register(ConnectedItemSelectorField, _ItemSelectorField["default"]);

  var _default = ConnectedItemSelectorField;
  exports["default"] = _default;
  //# sourceMappingURL=ItemSelectorField.es.js.map
});
//# sourceMappingURL=ItemSelectorField.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/ItemSelectorField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/floating_toolbar/fragment_configuration/field_types/ItemSelectorField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../../../common/AssetSelector.es', './ItemSelectorFieldDelegateTemplate.soy', '../../../../store/ConnectedComponent.es', '../../../../utils/FragmentsEditorDialogUtils', '../../../../utils/FragmentsEditorUpdateUtils.es', './ItemSelectorField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.ConnectedItemSelectorField = exports.ItemSelectorField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("../../../common/AssetSelector.es");

  require("./ItemSelectorFieldDelegateTemplate.soy");

  var _ConnectedComponent = _interopRequireDefault(require("../../../../store/ConnectedComponent.es"));

  var _FragmentsEditorDialogUtils = require("../../../../utils/FragmentsEditorDialogUtils");

  var _FragmentsEditorUpdateUtils = require("../../../../utils/FragmentsEditorUpdateUtils.es");

  var _ItemSelectorField = _interopRequireDefault(require("./ItemSelectorField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ItemSelectorField
   */
  var ItemSelectorField = /*#__PURE__*/function (_Component) {
    _inherits(ItemSelectorField, _Component);

    function ItemSelectorField() {
      _classCallCheck(this, ItemSelectorField);

      return _possibleConstructorReturn(this, _getPrototypeOf(ItemSelectorField).apply(this, arguments));
    }

    _createClass(ItemSelectorField, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var typeOptions = this.field.typeOptions;

        if (typeOptions) {
          var className = typeOptions.className,
              _typeOptions$enableSe = typeOptions.enableSelectTemplate,
              enableSelectTemplate = _typeOptions$enableSe === void 0 ? false : _typeOptions$enableSe;

          if (className) {
            nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['selectedClassName'], className);
          }

          nextState = (0, _FragmentsEditorUpdateUtils.setIn)(nextState, ['enableSelectTemplate'], enableSelectTemplate);
        }

        return nextState;
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "syncConfigurationValues",
      value: function syncConfigurationValues() {
        if (this.configurationValues && this.configurationValues[this.field.name] && this.configurationValues[this.field.name].className) {
          var className = this.configurationValues[this.field.name].className;
          var itemType = this.availableAssets.find(function (availableAsset) {
            return availableAsset.className === className;
          });
          this.availableTemplates = itemType.availableTemplates;
        } else {
          this.availableTemplates = [];
        }
      }
      /**
       * Handle the click in the plus button to open the dialog to select an item
       * @review
       */

    }, {
      key: "_handleItemSelectClick",
      value: function _handleItemSelectClick() {
        var className = this.field.typeOptions.className;
        var itemType = this.availableAssets.find(function (availableAsset) {
          return availableAsset.className === className;
        });

        if (itemType) {
          this._openAssetBrowser(itemType.href, itemType.typeName);
        }
      }
      /**
       *
       * @review
       */

    }, {
      key: "_handleSelectTemplateValueChanged",
      value: function _handleSelectTemplateValueChanged() {
        var targetElement = window.event.delegateTarget;
        var selectedItem = this.configurationValues[this.field.name];
        selectedItem.template = targetElement.options[targetElement.selectedIndex].value;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: selectedItem
        });
      }
      /**
       * Handle the click in the item type dropdown
       * @param {Event} event
       * @review
       */

    }, {
      key: "_handleItemTypeClick",
      value: function _handleItemTypeClick(event) {
        var _event$delegateTarget = event.delegateTarget.dataset,
            assetBrowserUrl = _event$delegateTarget.assetBrowserUrl,
            assetBrowserWindowTitle = _event$delegateTarget.assetBrowserWindowTitle;

        this._openAssetBrowser(assetBrowserUrl, assetBrowserWindowTitle);
      }
      /**
       * Opens asset browser
       * @param {string} assetBrowserURL
       * @param {string} assetBrowserWindowTitle
       * @review
       */

    }, {
      key: "_openAssetBrowser",
      value: function _openAssetBrowser(assetBrowserURL, assetBrowserWindowTitle) {
        var _this = this;

        (0, _FragmentsEditorDialogUtils.openAssetBrowser)({
          assetBrowserURL: assetBrowserURL,
          callback: function callback(selectedAssetEntry) {
            _this.emit('fieldValueChanged', {
              name: _this.field.name,
              value: {
                className: selectedAssetEntry.className,
                classNameId: selectedAssetEntry.classNameId,
                classPK: selectedAssetEntry.classPK,
                title: selectedAssetEntry.title
              }
            });
          },
          eventName: "".concat(this.portletNamespace, "selectAsset"),
          modalTitle: assetBrowserWindowTitle
        });
      }
    }]);

    return ItemSelectorField;
  }(_metalComponent["default"]);

  exports.ItemSelectorField = ItemSelectorField;
  ItemSelectorField.STATE = {
    /**
     * Available templates of the current className
     * @default []
     * @instance
     * @memberOf ItemSelectorField
     * @type {array}
     */
    availableTemplates: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      key: _metalState.Config.string(),
      label: _metalState.Config.string()
    })).internal().value([]),

    /**
     * Fragment Entry Link Configuration values
     * @instance
     * @memberOf ItemSelectorField
     * @type {object}
     */
    configurationValues: _metalState.Config.object(),

    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.string(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };
  var ConnectedItemSelectorField = (0, _ConnectedComponent["default"])(ItemSelectorField, ['availableAssets', 'portletNamespace', 'spritemap']);
  exports.ConnectedItemSelectorField = ConnectedItemSelectorField;

  _metalSoy["default"].register(ConnectedItemSelectorField, _ItemSelectorField["default"]);

  var _default = ConnectedItemSelectorField;
  exports["default"] = _default;
  //# sourceMappingURL=ItemSelectorField.es.js.map
});
//# sourceMappingURL=ItemSelectorField.es.js.map
